#include <iostream>
#include "objfile.h"

// Example code demonstrating the obj reader.
// Written by Christopher Twigg <cdtwigg@cs.cmu.edu>
// for 15-864 spring 2004.


int main( int argc, char** argv )
{
	if( argc != 2 )
	{
		std::cout << "Usage: " << argv[0] << " [obj file]" << std::endl;
		return 1;
	}

	ObjFile objFile( argv[1] );

	typedef std::vector<std::string> SVec;
	SVec groupNames = 
		objFile.groupNames();
	for( SVec::const_iterator nameItr = groupNames.begin();
		nameItr != groupNames.end();
		++nameItr )
	{
		std::cout << "Found obj group '" << *nameItr << std::endl;
		ObjFile::Group group = objFile.group( *nameItr );
		std::cout << "Iterating through group faces..." << std::endl;
		for( unsigned int iFace = 0; iFace < group.faceCount(); ++iFace )
		{
			ObjFile::Face face = group.face(iFace);
			if( face.vertexCount() == 3 )
				std::cout << "  found triangle ";
			else if( face.vertexCount() == 4 )
				std::cout << "  found quadrilateral ";
			else
				std::cout << "  found " << face.vertexCount() << "-gon ";

			// Since the vertex positions are unique within the files, we can
			// use these to cross-index the polygons.
			for( unsigned int iVertex = 0; iVertex < face.vertexCount(); ++iVertex )
			{
				if( iVertex != 0 )
					std::cout << " -> ";
				std::cout << face.vertex( iVertex ).position();
			}
			std::cout << std::endl;

			// Now we will retrieve positions, normals, and texture coordinates of the
			// files by indexing into the global vertex namespace.
			for( unsigned int iVertex = 0; iVertex < face.vertexCount(); ++iVertex )
			{
				ObjFile::Vertex vertex = face.vertex( iVertex );
				std::cout << "    vertex " << iVertex << "; " << std::endl;
				std::cout << "      position = " 
					<< objFile.vertexPosition( vertex.position() ) << ";" << std::endl;
				if( vertex.hasNormal() )
					std::cout << "      normal = " << objFile.normal( vertex.normal() ) << ";" << std::endl;
				if( vertex.hasTextureCoordinate() )
					std::cout << "      texture coordinate = " << 
						objFile.textureCoordinate( vertex.textureCoordinate() ) << ";" << std::endl;
			}
		}
	}
}


